@@ -1,3 +1,4 @@
+"""Validator class for all boxes in JP2"""
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -16,16 +17,15 @@
 from __future__ import division
 import uuid
 import math
-import config
-import etpatch as ET
-import byteconv as bc
-from shared import listOccurrencesAreContiguous
-from shared import printWarning
+from . import config as config
+from . import etpatch as ET
+from . import byteconv as bc
+from . import shared as shared
 
 
 class BoxValidator:
-    # Marker tags/codes that identify all sub-boxes as hexadecimal strings
-    #(Correspond to "Box Type" values, see ISO/IEC 15444-1 Section I.4)
+    """Marker tags/codes that identify all sub-boxes as hexadecimal strings
+    (Correspond to "Box Type" values, see ISO/IEC 15444-1 Section I.4)"""
     typeMap = {
         b'\x6a\x70\x32\x69': "intellectualPropertyBox",
         b'\x78\x6d\x6c\x20': "xmlBox",
@@ -89,10 +89,11 @@ class BoxValidator:
         self.bTypeString = bType
 
     def validate(self):
+        """Generic box validation function"""
         try:
             to_call = getattr(self, "validate_" + self.boxType)
         except AttributeError:
-            printWarning(
+            shared.printWarning(
                 "ignoring '" + self.boxType + "' (validator function not yet implemented)")
 
         else:
@@ -107,15 +108,15 @@ class BoxValidator:
 
     def _isValid(self):
         for elt in self.tests.iter():
-            if elt.text == False:
+            if elt.text is False:
                 # File didn't pass this test, so not valid
-                return(False)
-        return(True)
+                return False
+        return True
 
     def _getBox(self, byteStart, noBytes):
-        # Parse JP2 box and return information on its
-        # size, type and contents
-
+        """Parse JP2 box and return information on its
+        size, type and contents
+        """
         # Box length (4 byte unsigned integer)
         boxLengthValue = bc.bytesToUInt(
             self.boxContents[byteStart:byteStart + 4])
@@ -149,8 +150,9 @@ class BoxValidator:
         return (boxLengthValue, boxType, byteEnd, boxContents)
 
     def _getMarkerSegment(self, offset):
-        # Read marker segment that starts at offset and return marker, size,
-        # contents and start offset of next marker
+        """Read marker segment that starts at offset and return marker, size,
+        contents and start offset of next marker
+        """
 
         # First 2 bytes: 16 bit marker
         marker = self.boxContents[offset:offset + 2]
@@ -180,10 +182,11 @@ class BoxValidator:
         return(marker, length, contents, offsetNext)
 
     def _calculateCompressionRatio(self, noBytes, bPCDepthValues, height, width):
-        # Computes compression ratio
-        # noBytes: size of compressed image in bytes
-        # bPCDepthValues: list with bits per component for each component
-        # height, width: image height, width
+        """Computes compression ratio
+        - noBytes: size of compressed image in bytes
+        - bPCDepthValues: list with bits per component for each component
+        - height, width: image height, width
+        """
 
         # Total bits per pixel
         bitsPerPixel = 0
@@ -204,12 +207,13 @@ class BoxValidator:
             # Obviously something going wrong here ...
             compressionRatio = -9999
 
-        return(compressionRatio)
+        return compressionRatio
 
     def _getBitValue(self, n, p):
-        # Get the bit value of denary (base 10) number n at the equivalent binary
-        # position p (binary count starts at position 1 from the left)
-        # Only works if n can be expressed as 8 bits !!!
+        """Get the bit value of denary (base 10) number n at the equivalent binary
+        position p (binary count starts at position 1 from the left)
+        Only works if n can be expressed as 8 bits !!!
+        """
 
         # Word length in bits
         wordLength = 8
@@ -220,13 +224,11 @@ class BoxValidator:
         return (n >> shift) & 1
 
     def testFor(self, testType, testResult):
-        # Add testResult node to tests element tree
+        """Add testResult node to tests element tree"""
 
-        # print(config.outputVerboseFlag)
-
-        if config.outputVerboseFlag == False:
+        if config.outputVerboseFlag is False:
             # Non-verbose output: only add results of tests that failed
-            if testResult == False:
+            if testResult is False:
                 self.tests.appendChildTagWithText(testType, testResult)
 
         else:
@@ -234,39 +236,27 @@ class BoxValidator:
             self.tests.appendChildTagWithText(testType, testResult)
 
     def addCharacteristic(self, characteristic, charValue):
-        # Add characteristic node to characteristics element tree
+        """Add characteristic node to characteristics element tree"""
 
         self.characteristics.appendChildTagWithText(characteristic, charValue)
 
     # Validator functions for boxes
 
     def validate_unknownBox(self):
-
-        # Although jpylyzer doesn't "know" anything about this box, we
-        # can at least report the 4 characters from the Box Type field
-        # (TBox) here
+        """Process 'unknown'box. Although jpylyzer doesn't know anything about this box, we
+        can at least report the 4 characters from the Box Type field (TBox) here
+        """
 
         boxType = self.bTypeString
 
-        """"
-        # If boxType contains any device control characters (e.g. because of
-        # file corruption), replace them  with printable character
-        if bc.containsControlCharacters(boxType):
-            boxType=bc.replaceControlCharacters(boxType)
-
-        # Decode to string with Latin encoding
-        # Elementtree will deal with any non-ASCII characters by replacing
-        # them with numeric entity references
-        boxType=boxType.decode("iso-8859-15","strict")
-        """
-        # Add (cleaned up) boxType string to output
+        # Add boxType string to output
         self.addCharacteristic("boxType", boxType)
 
         # Print warning message to screen
-        printWarning("ignoring unknown box")
+        shared.printWarning("ignoring unknown box")
 
     def validate_signatureBox(self):
-        # Signature box (ISO/IEC 15444-1 Section I.5.2)
+        """Signature box (ISO/IEC 15444-1 Section I.5.2)"""
 
         # Check box size, which should be 4 bytes
         self.testFor("boxLengthIsValid", len(self.boxContents) == 4)
@@ -277,7 +267,7 @@ class BoxValidator:
             "signatureIsValid", self.boxContents[0:4] == b'\x0d\x0a\x87\x0a')
 
     def validate_fileTypeBox(self):
-        # File type box (ISO/IEC 15444-1 Section I.5.2)
+        """File type box (ISO/IEC 15444-1 Section I.5.2)"""
 
         # Determine number of compatibility fields from box length
         numberOfCompatibilityFields = (len(self.boxContents) - 8) / 4
@@ -319,13 +309,12 @@ class BoxValidator:
         self.testFor("compatibilityListIsValid", b'\x6a\x70\x32\x20' in cLList)
 
     def validate_jp2HeaderBox(self):
-        # JP2 header box (superbox) (ISO/IEC 15444-1 Section I.5.3)
+        """JP2 header box (superbox) (ISO/IEC 15444-1 Section I.5.3)"""
 
         # List for storing box type identifiers
         subBoxTypes = []
         noBytes = len(self.boxContents)
         byteStart = 0
-        bytesTotal = 0
 
         # Dummy value
         boxLengthValue = 10
@@ -353,7 +342,7 @@ class BoxValidator:
         self.testFor(
             "containsImageHeaderBox", self.boxTagMap['imageHeaderBox'] in subBoxTypes)
         self.testFor("containsColourSpecificationBox", self.boxTagMap[
-                     'colourSpecificationBox'] in subBoxTypes)
+            'colourSpecificationBox'] in subBoxTypes)
 
         # If bPCSign equals 1 and bPCDepth equals 128 (equivalent to bPC field being
         # 255), this box should contain a Bits Per Components box
@@ -362,13 +351,13 @@ class BoxValidator:
 
         if sign == 1 and depth == 128:
             self.testFor("containsBitsPerComponentBox", self.boxTagMap[
-                         'bitsPerComponentBox'] in subBoxTypes)
+                'bitsPerComponentBox'] in subBoxTypes)
 
         # Is the first box an Image Header Box?
         try:
             firstJP2HeaderBoxIsImageHeaderBox = subBoxTypes[
                 0] == self.boxTagMap['imageHeaderBox']
-        except:
+        except Exception:
             firstJP2HeaderBoxIsImageHeaderBox = False
 
         self.testFor(
@@ -376,7 +365,7 @@ class BoxValidator:
 
         # Some boxes can have multiple instances, whereas for others only one
         # is allowed
-        self.testFor("noMoreThanOneImageHeaderBox",  subBoxTypes.count(
+        self.testFor("noMoreThanOneImageHeaderBox", subBoxTypes.count(
             self.boxTagMap['imageHeaderBox']) <= 1)
         self.testFor("noMoreThanOneBitsPerComponentBox", subBoxTypes.count(
             self.boxTagMap['bitsPerComponentBox']) <= 1)
@@ -391,15 +380,16 @@ class BoxValidator:
 
         # In case of multiple colour specification boxes, they should appear contiguously
         # within the header box
-        colourSpecificationBoxesAreContiguous = listOccurrencesAreContiguous(
+        colourSpecificationBoxesAreContiguous = shared.listOccurrencesAreContiguous(
             subBoxTypes, self.boxTagMap['colourSpecificationBox'])
         self.testFor("colourSpecificationBoxesAreContiguous",
                      colourSpecificationBoxesAreContiguous)
 
         # If JP2 Header box contains a Palette Box, it should also contain a component
         # mapping box, and vice versa
-        if (self.boxTagMap['paletteBox'] in subBoxTypes and self.boxTagMap['componentMappingBox'] not in subBoxTypes) \
-                or (self.boxTagMap['componentMappingBox'] in subBoxTypes and self.boxTagMap['paletteBox'] not in subBoxTypes):
+        if ((self.boxTagMap['paletteBox'] in subBoxTypes and self.boxTagMap['componentMappingBox']
+             not in subBoxTypes) or (self.boxTagMap['componentMappingBox'] in subBoxTypes and
+                                     self.boxTagMap['paletteBox'] not in subBoxTypes)):
             paletteAndComponentMappingBoxesOnlyTogether = False
         else:
             paletteAndComponentMappingBoxesOnlyTogether = True
@@ -409,8 +399,9 @@ class BoxValidator:
 
     # Validator functions for boxes in JP2 Header superbox
     def validate_imageHeaderBox(self):
-        # Image header box (ISO/IEC 15444-1 Section I.5.3.1)
-        # This is a fixed-length box that contains generic image info.
+        """Image header box (ISO/IEC 15444-1 Section I.5.3.1)
+        This is a fixed-length box that contains generic image info.
+        """
 
         # Check box length (14 bytes, excluding box length/type fields)
         self.testFor("boxLengthIsValid", len(self.boxContents) == 14)
@@ -451,7 +442,7 @@ class BoxValidator:
         bPCDepthIsWithinAllowedRange = 1 <= bPCDepth <= 38
         bitDepthIsVariable = 1 <= bPC <= 255
 
-        if bPCDepthIsWithinAllowedRange == True or bitDepthIsVariable == True:
+        if bPCDepthIsWithinAllowedRange or bitDepthIsVariable:
             bPCIsValid = True
         else:
             bPCIsValid = False
@@ -480,8 +471,8 @@ class BoxValidator:
         self.testFor("iPRIsValid", 0 <= iPR <= 1)
 
     def validate_bitsPerComponentBox(self):
-        # bits per component box (ISO/IEC 15444-1 Section I.5.3.2)
-        # Optional box that specifies bit depth of each component
+        """bits per component box (ISO/IEC 15444-1 Section I.5.3.2)
+        Optional box that specifies bit depth of each component"""
 
         # Number of bPC field (each field is 1 byte)
         numberOfBPFields = len(self.boxContents)
@@ -508,9 +499,9 @@ class BoxValidator:
             self.testFor("bPCIsValid", 1 <= bPCDepth <= 38)
 
     def validate_colourSpecificationBox(self):
-        # Colour specification box (ISO/IEC 15444-1 Section I.5.3.3)
-        # This box defines one method for interpreting colourspace of decompressed
-        # image data
+        """Colour specification box (ISO/IEC 15444-1 Section I.5.3.3)
+        This box defines one method for interpreting colourspace of decompressed
+        image data"""
 
         # Length of this box
         length = len(self.boxContents)
@@ -596,11 +587,12 @@ class BoxValidator:
             self.characteristics.append(iccCharacteristics)
 
     def validate_icc(self):
-        # Extracts characteristics (property-value pairs) of ICC profile
-        # Note that although values are stored in  'text' property of sub-elements,
-        # they may have a type other than 'text' (binary string, integers, lists)
-        # This means that some post-processing (conversion to text) is needed to
-        # write these property-value pairs to XML
+        """Extracts characteristics (property-value pairs) of ICC profile
+        Note that although values are stored in  'text' property of sub-elements,
+        they may have a type other than 'text' (binary string, integers, lists)
+        This means that some post-processing (conversion to text) is needed to
+        write these property-value pairs to XML
+        """
 
         # Profile header properties (note: incomplete at this stage!)
 
@@ -791,13 +783,14 @@ class BoxValidator:
 
             # Description as binary string (excluding terminating null char)
             description = descTag[12:12 + descriptionLength - 1]
-        except:
+        except Exception:
             description = ""
         self.addCharacteristic("description", description)
 
     def validate_paletteBox(self):
-        # Palette box (ISO/IEC 15444-1 Section I.5.3.4)
-        # Optional box that specifies a palette
+        """Palette box (ISO/IEC 15444-1 Section I.5.3.4)
+        Optional box that specifies a palette
+        """
 
         # Number of entries in the table (each field is 2 bytes)
         nE = bc.bytesToUShortInt(self.boxContents[0:2])
@@ -855,9 +848,10 @@ class BoxValidator:
                 offset += bytesPadded
 
     def validate_componentMappingBox(self):
-        # Component mapping box (ISO/IEC 15444-1 Section I.5.3.5)
-        # This box defines how image channels are identified from actual
-        # components
+        """Component mapping box (ISO/IEC 15444-1 Section I.5.3.5)
+        This box defines how image channels are identified from actual
+        components
+        """
 
         # Determine number of channels from box length
         numberOfChannels = int(len(self.boxContents) / 4)
@@ -898,9 +892,10 @@ class BoxValidator:
             offset += 4
 
     def validate_channelDefinitionBox(self):
-        # Channel definition box (ISO/IEC 15444-1 Section I.5.3.6)
-        # This box specifies the meaning of the samples in each channel in the
-        # image
+        """Channel definition box (ISO/IEC 15444-1 Section I.5.3.6)
+        This box specifies the meaning of the samples in each channel in the
+        image
+        """
 
         # Number of channel descriptions (short integer)
         n = bc.bytesToUShortInt(self.boxContents[0:2])
@@ -942,9 +937,10 @@ class BoxValidator:
             offset += 6
 
     def validate_resolutionBox(self):
-        # Resolution box (superbox)(ISO/IEC 15444-1 Section I.5.3.7
-        # Specifies the capture and/or default display grid resolutions of
-        # the image.
+        """Resolution box (superbox)(ISO/IEC 15444-1 Section I.5.3.7
+        Specifies the capture and/or default display grid resolutions of
+        the image.
+        """
 
         # Marker tags/codes that identify all sub-boxes as hexadecimal strings
         tagCaptureResolutionBox = b'\x72\x65\x73\x63'
@@ -955,7 +951,6 @@ class BoxValidator:
 
         noBytes = len(self.boxContents)
         byteStart = 0
-        bytesTotal = 0
 
         # Dummy value
         boxLengthValue = 10
@@ -983,7 +978,8 @@ class BoxValidator:
         # This box contains either one Capture Resolution box, one Default Display
         # resolution box, or one of both
         self.testFor("containsCaptureOrDisplayResolutionBox",
-                     tagCaptureResolutionBox in subBoxTypes or tagDisplayResolutionBox in subBoxTypes)
+                     tagCaptureResolutionBox in subBoxTypes or
+                     tagDisplayResolutionBox in subBoxTypes)
         self.testFor("noMoreThanOneCaptureResolutionBox",
                      subBoxTypes.count(tagCaptureResolutionBox) <= 1)
         self.testFor("noMoreThanOneDisplayResolutionBox",
@@ -992,7 +988,7 @@ class BoxValidator:
     # Validator functions for boxes in Resolution box
 
     def validate_captureResolutionBox(self):
-        # Capture  Resolution Box (ISO/IEC 15444-1 Section I.5.3.7.1)
+        """Capture  Resolution Box (ISO/IEC 15444-1 Section I.5.3.7.1)"""
 
         # Check box size, which should be 10 bytes
         self.testFor("boxLengthIsValid", len(self.boxContents) == 10)
@@ -1052,7 +1048,7 @@ class BoxValidator:
             "hRescInPixelsPerInch", round(hRescInPixelsPerInch, 2))
 
     def validate_displayResolutionBox(self):
-        # Default Display  Resolution Box (ISO/IEC 15444-1 Section I.5.3.7.2)
+        """Default Display  Resolution Box (ISO/IEC 15444-1 Section I.5.3.7.2)"""
 
         # Check box size, which should be 10 bytes
         self.testFor("boxLengthIsValid", len(self.boxContents) == 10)
@@ -1112,7 +1108,7 @@ class BoxValidator:
             "hResdInPixelsPerInch", round(hResdInPixelsPerInch, 2))
 
     def validate_contiguousCodestreamBox(self):
-        # Contiguous codestream box (ISO/IEC 15444-1 Section I.5.4)
+        """Contiguous codestream box (ISO/IEC 15444-1 Section I.5.4)"""
 
         # Codestream length
         length = len(self.boxContents)
@@ -1264,9 +1260,9 @@ class BoxValidator:
         if not numberOfTilesExpected:
             numberOfTilesExpected = 0
 
-        # Impose upper limit on numberOfTilesExpected to avoid misbehaviour in case of corrupted files
-        # Value of 65535 equals upper value imposed by Kakadu (can't find this
-        # anywhere in the standard though)
+        # Impose upper limit on numberOfTilesExpected to avoid misbehaviour in case of corrupted
+        # files. Value of 65535 equals upper value imposed by Kakadu (can't find this  anywhere
+        # in the standard though)
         numberOfTilesExpected = min(numberOfTilesExpected, 65535)
 
         # Create list with one entry for each tile
@@ -1303,8 +1299,6 @@ class BoxValidator:
                 tilePartCharacteristics.append(characteristicsTilePart)
 
                 tileIndex = characteristicsTilePart.findElementText('sot/isot')
-                tilePartIndex = characteristicsTilePart.findElementText(
-                    'sor/tpsot')
                 tilePartsOfTile = characteristicsTilePart.findElementText(
                     'sot/tnsot')
 
@@ -1347,8 +1341,9 @@ class BoxValidator:
     # Validator functions for codestream elements
 
     def validate_siz(self):
-        # Image and tile size (SIZ) header fields (ISO/IEC 15444-1 Section
-        # A.5.1)
+        """Image and tile size (SIZ) header fields (ISO/IEC 15444-1 Section
+        A.5.1)
+        """
 
         # Length of main image header
         lsiz = bc.bytesToUShortInt(self.boxContents[0:2])
@@ -1489,8 +1484,9 @@ class BoxValidator:
             offset += 3
 
     def validate_cod(self):
-        # Coding style default (COD) header fields (ISO/IEC 15444-1 Section
-        # A.6.1)
+        """Coding style default (COD) header fields (ISO/IEC 15444-1 Section
+        A.6.1)
+        """
 
         # Length of COD marker
         lcod = bc.bytesToUShortInt(self.boxContents[0:2])
@@ -1681,8 +1677,9 @@ class BoxValidator:
                 offset += 1
 
     def validate_qcd(self):
-        # Quantization default  (QCD) header fields (ISO/IEC 15444-1 Section
-        # A.6.4)
+        """Quantization default  (QCD) header fields (ISO/IEC 15444-1 Section
+        A.6.4)
+        """
 
         # Length of QCD marker
         lqcd = bc.bytesToUShortInt(self.boxContents[0:2])
@@ -1760,7 +1757,7 @@ class BoxValidator:
         # of corresponding equations (need Annex E from standard for that)
 
     def validate_com(self):
-        # Codestream comment (COM) (ISO/IEC 15444-1 Section A.9.2)
+        """Codestream comment (COM) (ISO/IEC 15444-1 Section A.9.2)"""
 
         # Length of COM marker
         lcom = bc.bytesToUShortInt(self.boxContents[0:2])
@@ -1782,33 +1779,41 @@ class BoxValidator:
         # Contents (multiples of Ccom)
         comment = self.boxContents[4:lcom]
 
-        # Decode to string with Latin encoding, determine if valid ISO 8859-15
-
-        try:
-            comment = comment.decode("iso-8859-15", "strict")
-        except:
-            # Empty string in case of decode error
-            comment = ""
-
-        # Ideally decode above should raise exception if comment is not valid
-        # ISO 8859-15, but this doesn't work. So instead we do this indirectly
-        # by looking for control characters (tab, newline and carriage return
-        # are OK)
-        if bc.removeControlCharacters(comment) == comment:
+        if rcom == 0:
+            # no validation of binary comment content
             commentIsValid = True
-        else:
-            commentIsValid = False
+            comment = bc.bytesToHex(comment)
+
+        elif rcom == 1:
+
+            # Decode to string with Latin encoding, determine if valid ISO
+            # 8859-15
+
+            try:
+                comment = comment.decode("iso-8859-15", "strict")
+            except UnicodeError:
+                # Empty string in case of decode error
+                comment = ""
+
+            # Ideally decode above should raise exception if comment is not
+            # valid ISO 8859-15, but this doesn't work. So instead we do this
+            # indirectly by looking for control characters (tab, newline and
+            # carriage return are OK)
+            if bc.removeControlCharacters(comment) == comment:
+                commentIsValid = True
+            else:
+                commentIsValid = False
 
         self.testFor("commentIsValid", commentIsValid)
 
-        # Only add comment to characteristics if text (may contain binary data
-        # if rcom is 0!)
-        if rcom == 1:
+        # any non-printable data should have been removed.
+        if commentIsValid:
             self.addCharacteristic("comment", comment)
 
     def validate_sot(self):
-        # Start of tile-part (SOT) marker segment (ISO/IEC 15444-1 Section
-        # A.4.2)
+        """Start of tile-part (SOT) marker segment (ISO/IEC 15444-1 Section
+        A.4.2)
+        """
 
         # Note that unlike other marker validation functions this one returns a
         # third result, which is the total tile-part length (psot)!
@@ -1835,7 +1840,7 @@ class BoxValidator:
 
         # psot equals 0 (for last tile part) or greater than 14 (so range 1-13
         # is illegal)
-        psotIsValid = not(1 <= psot <= 13)
+        psotIsValid = not 1 <= psot <= 13
         self.testFor("psotIsValid", psotIsValid)
 
         # Tile part index
@@ -1861,52 +1866,55 @@ class BoxValidator:
     # because there will be either lots of them or none at all!).
 
     def validate_coc(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_rgn(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_qcc(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_poc(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_tlm(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_plm(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_plt(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_ppm(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_ppt(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_crg(self):
-        # Empty function
+        """Empty function"""
         pass
 
     def validate_tilePart(self):
-        # Analyse tile part that starts at offsetStart and perform cursory validation
-        # Precondition: offsetStart points to SOT marker
-        #
-        # Limitations:
-        # - COD, COC, QCD, QCC and RGN are markers only allowed in first tile-part
-        #   of a tile; there is currently no check on this (may be added later)
+        """Analyse tile part that starts at offsetStart and perform cursory validation
+
+        Precondition: offsetStart points to SOT marker
+
+        Limitations:
+
+         - COD, COC, QCD, QCC and RGN are markers only allowed in first tile-part
+           of a tile; there is currently no check on this (may be added later)
+        """
 
         offset = self.startOffset
 
@@ -1929,17 +1937,14 @@ class BoxValidator:
 
         offset = offsetNext
 
-        # Last marker in every tile-part should be a start of data marker
-        foundSODMarker = False
-
         # Loop through remaining tile part marker segments; extract properties of
         # and validate COD, QCD and COM marker segments. Also test for presence of
         # SOD marker
         # NOTE 1: limited testing so far because of unavailability of test images with these
         # markers at tile-part level!!
-        # NOTE 2: check for offsetNext !=-9999 was included after encountering image with corruption
-        # that resulted in nonsensical lsot values, ultimatelty leading to an infinite loop. Shouldn't happen
-        # anymore (although this may not be the most elegant way of handling
+        # NOTE 2: check for offsetNext !=-9999 was included after encountering image with
+        # corruption that resulted in nonsensical lsot values, ultimatelty leading to an infinite
+        # loop. Shouldn't happen anymore (although this may not be the most elegant way of handling
         # this)
 
         while marker != b'\xff\x93' and offsetNext != -9999:
@@ -2035,7 +2040,7 @@ class BoxValidator:
         self.returnOffset = offsetNextTilePart
 
     def validate_xmlBox(self):
-        # XML Box (ISO/IEC 15444-1 Section I.7.1)
+        """XML Box (ISO/IEC 15444-1 Section I.7.1)"""
 
         data = self.boxContents
 
@@ -2050,30 +2055,31 @@ class BoxValidator:
 
             # If no exception was raised data contains well-formed XML
             containsWellformedXML = True
-        except:
+        except Exception:
             # If parse raised error this is not well-formed XML
             containsWellformedXML = False
 
             # Useful for extracting null-terminated XML (older Kakadu versions)
-            if config.extractNullTerminatedXMLFlag == True:
+            if config.extractNullTerminatedXMLFlag:
                 try:
                     data = bc.removeNullTerminator(data)
                     dataAsElement = ET.fromstring(data)
                     self.characteristics.append(dataAsElement)
-                except:
+                except Exception:
                     pass
 
         self.testFor("containsWellformedXML", containsWellformedXML)
 
     def validate_uuidBox(self):
-        # UUID Box (ISO/IEC 15444-1 Section I.7.2)
-        # For details on UUIDs see: http://tools.ietf.org/html/rfc4122.html
+        """UUID Box (ISO/IEC 15444-1 Section I.7.2)
+        For details on UUIDs see: http://tools.ietf.org/html/rfc4122.html
 
-        # Box contains 16-byte identifier, followed by block of data.
-        # Format of data is defined outside of the scope of JPEG 2000,
-        # so in most cases there's not much to validate here. Exception:
-        # if uuid = be7acfcb-97a9-42e8-9c71-999491e3afac this indicates
-        # presence of XMP metadata
+        Box contains 16-byte identifier, followed by block of data.
+        Format of data is defined outside of the scope of JPEG 2000,
+        so in most cases there's not much to validate here. Exception:
+        if uuid = be7acfcb-97a9-42e8-9c71-999491e3afac this indicates
+        presence of XMP metadata
+        """
 
         boxLength = len(self.boxContents)
 
@@ -2082,9 +2088,9 @@ class BoxValidator:
 
         # First 16 bytes contain UUID, convert to string of hex digits
         # in standard form
-        id = str(uuid.UUID(bytes=self.boxContents[0:16]))
+        boxUUID = str(uuid.UUID(bytes=self.boxContents[0:16]))
 
-        if id == "be7acfcb-97a9-42e8-9c71-999491e3afac":
+        if boxUUID == "be7acfcb-97a9-42e8-9c71-999491e3afac":
             # XMP packet
             data = self.boxContents[16:boxLength]
 
@@ -2105,7 +2111,7 @@ class BoxValidator:
 
                 # Useful for extracting null-terminated XML (older Kakadu
                 # versions)
-                if config.extractNullTerminatedXMLFlag == True:
+                if config.extractNullTerminatedXMLFlag:
                     try:
                         data = bc.removeNullTerminator(data)
                         dataAsElement = ET.fromstring(data)
@@ -2116,13 +2122,12 @@ class BoxValidator:
             self.testFor("containsWellformedXML", containsWellformedXML)
         else:
             # Only add to UUID to characteristics tree
-            self.addCharacteristic("uuid", id)
+            self.addCharacteristic("uuid", boxUUID)
 
     def validate_uuidInfoBox(self):
-        # UUID Info box (superbox)(ISO/IEC 15444-1 Section I.7.3)
-        # Provides additional information on vendor-specific UUIDs
-
-        # NOTE: Untested at this stage due to lack of suitable test files!!!
+        """UUID Info box (superbox)(ISO/IEC 15444-1 Section I.7.3)
+        Provides additional information on vendor-specific UUIDs
+        """
 
         # Marker tags/codes that identify sub-boxes as hexadecimal strings
         tagListBox = b'\x75\x6c\x73\x74'
@@ -2133,7 +2138,6 @@ class BoxValidator:
 
         noBytes = len(self.boxContents)
         byteStart = 0
-        bytesTotal = 0
 
         # Dummy value
         boxLengthValue = 10
@@ -2163,10 +2167,9 @@ class BoxValidator:
         self.testFor("containsOneURLBox", subBoxTypes.count(tagURLBox) == 1)
 
     def validate_uuidListBox(self):
-        # UUID List box (ISO/IEC 15444-1 Section I.7.3.1)
-        # Contains a list of UUIDs
-
-        # NOTE: Untested at this stage due to lack of suitable test files!!!
+        """UUID List box (ISO/IEC 15444-1 Section I.7.3.1)
+        Contains a list of UUIDs
+        """
 
         # Number of UUIDs
         nU = bc.bytesToUShortInt(self.boxContents[0:2])
@@ -2178,14 +2181,15 @@ class BoxValidator:
         # Loop through all UUIDs
         offset = 2
         for i in range(nU):
-            id = str(uuid.UUID(bytes=self.boxContents[offset:offset + 16]))
-            self.addCharacteristic("uuid", id)
+            boxUUID = str(uuid.UUID(bytes=self.boxContents[offset:offset + 16]))
+            self.addCharacteristic("uuid", boxUUID)
             offset += 16
 
     def validate_urlBox(self):
-        # Data Entry URL box (ISO/IEC 15444-1 Section I.7.3.2)
-        # Contains URL that can be used to obtain more information
-        # about UUIDs in UUID List box
+        """Data Entry URL box (ISO/IEC 15444-1 Section I.7.3.2)
+        Contains URL that can be used to obtain more information
+        about UUIDs in UUID List box
+        """
 
         # Version number (1 byte unsigned integer)
         version = bc.bytesToUnsignedChar(self.boxContents[0:1])
@@ -2211,16 +2215,9 @@ class BoxValidator:
         # Remove null character as this cannot be represented as XML
         loc = bc.removeNullTerminator(loc)
 
-        """
-        # If loc contains any device control characters (e.g. because of
-        # file corruption), replace them  with printable character
-        if bc.containsControlCharacters(loc):
-            loc=bc.replaceControlCharacters(loc)
-        """
-
         # Try decode to UTF-8
         try:
-            tmp = loc.decode("utf-8", "strict")
+            loc.decode("utf-8", "strict")
             self.testFor("locIsUTF8", True)
         except UnicodeDecodeError:
             self.testFor("locIsUTF8", False)
@@ -2228,19 +2225,21 @@ class BoxValidator:
         self.addCharacteristic("loc", loc)
 
     def validate_JP2(self):
-        # Top-level function for JP2 validation:
-        #
-        # 1. Parses all top-level boxes in JP2 byte object, and calls separate validator
-        #	function for each of these
-        # 2. Checks for presence of all required top-level boxes
-        # 3. Checks if JP2 header properties are consistent with corresponding properties
-        #	in codestream header
+        """Top-level function for JP2 validation:
+
+        1. Parses all top-level boxes in JP2 byte object, and calls separate validator
+           function for each of these
+        2. Checks for presence of all required top-level boxes
+        3. Checks if JP2 header properties are consistent with corresponding properties
+           in codestream header
+        """
 
         # Marker tags/codes that identify all top level boxes as hexadecimal strings
-        #(Correspond to "Box Type" values, see ISO/IEC 15444-1 Section I.4)
+        # (Correspond to "Box Type" values, see ISO/IEC 15444-1 Section I.4)
         tagSignatureBox = b'\x6a\x50\x20\x20'
         tagFileTypeBox = b'\x66\x74\x79\x70'
         tagJP2HeaderBox = b'\x6a\x70\x32\x68'
+        tagIntellectualPropertyBox = b'\x6a\x70\x32\x69'
         tagContiguousCodestreamBox = b'\x6a\x70\x32\x63'
 
         # List for storing box type identifiers
@@ -2248,7 +2247,6 @@ class BoxValidator:
 
         noBytes = len(self.boxContents)
         byteStart = 0
-        bytesTotal = 0
 
         # Dummy value
         boxLengthValue = 10
@@ -2298,17 +2296,17 @@ class BoxValidator:
         # Is the first box a Signature Box (ISO/IEC 15444-1 Section I.5.1)?
         try:
             firstBoxIsSignatureBox = boxTypes[0] == tagSignatureBox
-        except:
+        except Exception:
             firstBoxIsSignatureBox = False
 
         # Is the second box a File Type Box (ISO/IEC 15444-1 Section I.5.2)?
         try:
             secondBoxIsFileTypeBox = boxTypes[1] == tagFileTypeBox
-        except:
+        except Exception:
             secondBoxIsFileTypeBox = False
 
         # JP2 Header Box: after File Type box, before (first) contiguous codestream box
-        #(ISO/IEC 15444-1 Section I.5.3)?
+        # (ISO/IEC 15444-1 Section I.5.3)?
         try:
             positionJP2HeaderBox = boxTypes.index(tagJP2HeaderBox)
             positionFirstContiguousCodestreamBox = boxTypes.index(
@@ -2318,7 +2316,7 @@ class BoxValidator:
                 locationJP2HeaderBoxIsValid = True
             else:
                 locationJP2HeaderBoxIsValid = False
-        except:
+        except Exception:
             locationJP2HeaderBoxIsValid = False
 
         self.testFor("firstBoxIsSignatureBox", firstBoxIsSignatureBox)
@@ -2356,7 +2354,7 @@ class BoxValidator:
         # integer. Probably a bug in ET. Using 'find' + text property does work
         # as expected
 
-        if jp2ImageHeader != None and sizHeader != None:
+        if jp2ImageHeader is not None and sizHeader is not None:
 
             # Height should be equal to ysiz -yOsiz
 
@@ -2389,7 +2387,7 @@ class BoxValidator:
             #
             # 1. bPCSign and bPCDepth same for all components --> use values from image header
             # 2. bPCSign and bPCDepth vary across components --> use values from Bits Per
-            #	Components box
+            # -- Components box
             #
             # Situation 1 is the most common one. Situation 2 can be identified by a value
             # of 255 of bPC in the image header, which corresponds to  bPCSign = 1
