@@ -1,24 +1,24 @@
 #! /usr/bin/env python
 #
-#
-#
-# jpylyzer
-#
-# Requires: Python 2.7 (older versions won't work) OR Python 3.2 or more recent
-#  (Python 3.0 and 3.1 won't work either!)
-#
-# Copyright (C) 2011 - 2014 Johan van der Knijff, Koninklijke Bibliotheek -
-#  National Library of the Netherlands
-#
-# Contributors:
-#   Rene van der Ark (refactoring of original code)
-#   Lars Buitinck
-#   Adam Retter, The National Archives, UK. <adam.retter@googlemail.com>
-#   Jaishree Davey, The National Archives, UK.
-#   Laura Damian, The National Archives, UK.
-#   Carl Wilson, Open Planets Foundation, UK.
-#   Stefan Weil, UB Mannheim, DE.
-#
+"""Jpylyzer validator for JPEG 200 Part 1 (JP2) images
+
+ Requires: Python 2.7 (older versions won't work) OR Python 3.2 or more recent
+  (Python 3.0 and 3.1 won't work either!)
+
+ Copyright (C) 2011 - 2017 Johan van der Knijff, Koninklijke Bibliotheek -
+  National Library of the Netherlands
+
+Contributors:
+   Rene van der Ark, NL (refactoring of original code).
+   Lars Buitinck, NL.
+   Adam Retter, The National Archives, UK.
+   Jaishree Davey, The National Archives, UK.
+   Laura Damian, The National Archives, UK.
+   Carl Wilson, Open Planets Foundation, UK.
+   Stefan Weil, UB Mannheim, DE.
+   Adam Fritzler, Planet Labs, USA.
+"""
+
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -36,28 +36,26 @@ import sys
 import mmap
 import os
 import time
-import imp
 import glob
-import struct
 import argparse
-import config
 import codecs
 import re
-import etpatch as ET
-import fnmatch
-import xml.etree.ElementTree as ETree
-from boxvalidator import BoxValidator
 from xml.dom import minidom
-from byteconv import bytesToText
-from shared import printWarning
-scriptPath, scriptName = os.path.split(sys.argv[0])
+import xml.etree.ElementTree as ETree
 from six import u
+from . import config as config
+from . import etpatch as ET
+from . import boxvalidator as bv
+from . import shared as shared
+
+
+scriptPath, scriptName = os.path.split(sys.argv[0])
 
 # scriptName is empty when called from Java/Jython, so this needs a fix
 if len(scriptName) == 0:
     scriptName = 'jpylyzer'
 
-__version__ = "1.17.0"
+__version__ = "1.18.0"
 
 # Create parser
 parser = argparse.ArgumentParser(
@@ -66,35 +64,17 @@ parser = argparse.ArgumentParser(
 # list of existing files to be analysed
 existingFiles = []
 
+# Name space and schema strings
+nsString = 'http://openpreservation.org/ns/jpylyzer/'
+xsiNsString = 'http://www.w3.org/2001/XMLSchema-instance'
+locSchemaString = 'http://openpreservation.org/ns/jpylyzer/ \
+http://jpylyzer.openpreservation.org/jpylyzer-v-1-1.xsd'
 
-def main_is_frozen():
-    return (hasattr(sys, "frozen") or  # new py2exe
-            hasattr(sys, "importers")  # old py2exe
-            or imp.is_frozen("__main__"))  # tools/freeze
-
-
-def get_main_dir():
-    if main_is_frozen():
-        return os.path.dirname(sys.executable)
-    return os.path.dirname(sys.argv[0])
-
-
-def readFileBytes(file):
-    # Read file, return contents as a byte object
-
-    # Open file
-    f = open(file, "rb")
-
-    # Put contents of file into a byte object.
-    fileData = f.read()
-    f.close()
-
-    return(fileData)
 
 def generatePropertiesRemapTable():
-
-    # Generates nested dictionary which is used to map 'raw' property values
-    # (mostly integer values) to corresponding text descriptions
+    """Generates nested dictionary which is used to map 'raw' property values
+    (mostly integer values) to corresponding text descriptions
+    """
 
     # Master dictionary for mapping of text descriptions to enumerated values
     # Key: corresponds to parameter tag name
@@ -259,13 +239,14 @@ def generatePropertiesRemapTable():
     enumerationsMap['qStyle'] = qStyleMap
     enumerationsMap['rcom'] = registrationMap
 
-    return(enumerationsMap)
+    return enumerationsMap
 
-def fileToMemoryMap(file):
-    # Read contents of file to memory map object
 
-    # Open file
-    f = open(file, "rb")
+def fileToMemoryMap(filename):
+    """Read contents of filename to memory map object"""
+
+    # Open filename
+    f = open(filename, "rb")
 
     # Call to mmap is different on Linux and Windows, so we need to know
     # the current platform
@@ -282,12 +263,13 @@ def fileToMemoryMap(file):
     except ValueError:
         # mmap fails on empty files.
         fileData = ""
-    
-    f.close()    
-    return(fileData)  
 
-def checkOneFile(file):
-    # Process one file and return analysis result as element object
+    f.close()
+    return fileData
+
+
+def checkOneFile(path):
+    """Process one file and return analysis result as element object"""
 
     # Create output elementtree object
 
@@ -297,34 +279,33 @@ def checkOneFile(file):
         root = ET.Element('jpylyzer')
     else:
         root = ET.Element(
-            'jpylyzer', {'xmlns': 'http://openpreservation.org/ns/jpylyzer/',
-                         'xmlns:xsi': 'http://www.w3.org/2001/XMLSchema-instance',
-                         'xsi:schemaLocation': 'http://openpreservation.org/ns/jpylyzer/ http://jpylyzer.openpreservation.org/jpylyzer-v-1-1.xsd'})
+            'jpylyzer', {'xmlns': nsString,
+                         'xmlns:xsi': xsiNsString,
+                         'xsi:schemaLocation': locSchemaString})
 
     # Create elements for storing tool, file and status meta info
     toolInfo = ET.Element('toolInfo')
     fileInfo = ET.Element('fileInfo')
     statusInfo = ET.Element('statusInfo')
 
-    # File name and path 
-    fileName = os.path.basename(file)
-    filePath = os.path.abspath(file)
+    # File name and path
+    fileName = os.path.basename(path)
+    filePath = os.path.abspath(path)
 
     # If file name / path contain any surrogate pairs, remove them to
     # avoid problems when writing to XML
     fileNameCleaned = stripSurrogatePairs(fileName)
     filePathCleaned = stripSurrogatePairs(filePath)
 
-
     # Produce some general tool and file meta info
     toolInfo.appendChildTagWithText("toolName", scriptName)
     toolInfo.appendChildTagWithText("toolVersion", __version__)
     fileInfo.appendChildTagWithText("fileName", fileNameCleaned)
     fileInfo.appendChildTagWithText("filePath", filePathCleaned)
     fileInfo.appendChildTagWithText(
-        "fileSizeInBytes", str(os.path.getsize(file)))
+        "fileSizeInBytes", str(os.path.getsize(path)))
     try:
-        lastModifiedDate = time.ctime(os.path.getmtime(file))
+        lastModifiedDate = time.ctime(os.path.getmtime(path))
     except ValueError:
         # Dates earlier than 1 Jan 1970 can raise ValueError on Windows
         # Workaround: replace by lowest possible value (typically 1 Jan 1970)
@@ -334,12 +315,12 @@ def checkOneFile(file):
 
     # Initialise success flag
     success = True
-    
+
     try:
         # Contents of file to memory map object
-        fileData = fileToMemoryMap(file)
-        isValidJP2, tests, characteristics = BoxValidator("JP2", fileData).validate()
-        
+        fileData = fileToMemoryMap(path)
+        isValidJP2, tests, characteristics = bv.BoxValidator("JP2", fileData).validate()
+
         if fileData != "":
             fileData.close()
 
@@ -349,7 +330,7 @@ def checkOneFile(file):
         # Create printable version of tests and characteristics tree
         tests.makeHumanReadable()
         characteristics.makeHumanReadable(remapTable)
-    except Exception as ex:    
+    except Exception as ex:
         isValidJP2 = False
         success = False
         exceptionType = type(ex)
@@ -363,15 +344,15 @@ def checkOneFile(file):
         else:
             failureMessage = "unknown error (please report to developers)"
 
-        printWarning(failureMessage)
+        shared.printWarning(failureMessage)
         tests = ET.Element("tests")
         characteristics = ET.Element('properties')
- 
+
     # Add status info
     statusInfo.appendChildTagWithText("success", str(success))
-    if success == False:
-        statusInfo.appendChildTagWithText("failureMessage",failureMessage)
-  
+    if not success:
+        statusInfo.appendChildTagWithText("failureMessage", failureMessage)
+
     # Append all results to root
     root.append(toolInfo)
     root.append(fileInfo)
@@ -380,11 +361,13 @@ def checkOneFile(file):
     root.append(tests)
     root.append(characteristics)
 
-    return(root)
+    return root
+
 
 def checkNullArgs(args):
-    # This method checks if the input arguments list and exits program if
-    # invalid or no input argument is supplied.
+    """This method checks if the input arguments list and exits program if
+    invalid or no input argument is supplied.
+    """
 
     if len(args) == 0:
 
@@ -394,23 +377,25 @@ def checkNullArgs(args):
 
 
 def checkNoInput(files):
-    # Check if input arguments list results in any existing input files at all
-    # (and exits if not)
+    """Check if input arguments list results in any existing input files at all
+    (and exits if not)
+    """
 
     if len(files) == 0:
-        printWarning("no images to check!")
+        shared.printWarning("no images to check!")
         sys.exit(config.ERR_CODE_NO_IMAGES)
 
 
 def printHelpAndExit():
-    # Print help message and exit
+    """Print help message and exit"""
     print('')
     parser.print_help()
     sys.exit()
 
+
 def stripSurrogatePairs(ustring):
 
-    # Removes surrogate pairs from a Unicode string
+    """Removes surrogate pairs from a Unicode string"""
 
     # This works for Python 3.x, but not for 2.x!
     # Source: http://stackoverflow.com/q/19649463/1209004
@@ -420,7 +405,7 @@ def stripSurrogatePairs(ustring):
             ustring.encode('utf-8')
         except UnicodeEncodeError:
             # Strip away surrogate pairs
-            tmp = ustring.encode('utf-8', 'surrogateescape')
+            tmp = ustring.encode('utf-8', 'replace')
             ustring = tmp.decode('utf-8', 'ignore')
 
     # In Python 2.x we need to use regex
@@ -441,21 +426,16 @@ def stripSurrogatePairs(ustring):
             [\udc00-\udfff]      #   match trailing surrogate
             )                   # end group
             """))
-   
-        # Remove surrogates (i.e. replace by empty string) 
-        tmp = lone.sub(r'',ustring).encode('utf-8')
+
+        # Remove surrogates (i.e. replace by empty string)
+        tmp = lone.sub(r'', ustring).encode('utf-8')
         ustring = tmp.decode('utf-8')
 
-    return(ustring)
-
-def getFilesFromDir(dirpath):
-    for fp in os.listdir(dirpath):
-        filepath = os.path.join(dirpath, fp)
-        if os.path.isfile(filepath):
-            existingFiles.append(filepath)
+    return ustring
 
 
 def getFiles(searchpattern):
+    """Append paths of all files that match search pattern to existingFiles"""
     results = glob.glob(searchpattern)
     for f in results:
         if os.path.isfile(f):
@@ -463,9 +443,9 @@ def getFiles(searchpattern):
 
 
 def getFilesWithPatternFromTree(rootDir, pattern):
-    # Recurse into directory tree and return list of all files
-    # NOTE: directory names are disabled here!!
-
+    """Recurse into directory tree and return list of all files
+    NOTE: directory names are disabled here!!
+    """
     for dirname, dirnames, filenames in os.walk(rootDir):
         # Suppress directory names
         for subdirname in dirnames:
@@ -474,9 +454,11 @@ def getFilesWithPatternFromTree(rootDir, pattern):
             searchpattern = os.path.join(thisDirectory, pattern)
             getFiles(searchpattern)
 
+
 def getFilesFromTree(rootDir):
-    # Recurse into directory tree and return list of all files
-    # NOTE: directory names are disabled here!!
+    """Recurse into directory tree and return list of all files
+    NOTE: directory names are disabled here!!
+    """
 
     for dirname, dirnames, filenames in os.walk(rootDir):
         # Suppress directory names
@@ -489,12 +471,13 @@ def getFilesFromTree(rootDir):
 
 
 def findFiles(recurse, paths):
+    """Find all files that match a wildcard expression and add their paths to existingFiles"""
 
     WILDCARD = "*"
 
     # process the list of input paths
     for root in paths:
-    
+
         if config.PYTHON_VERSION.startswith(config.PYTHON_2):
             # Convert root to UTF-8 (only needed for Python 2.x)
             root = unicode(root, 'utf-8')
@@ -507,7 +490,7 @@ def findFiles(recurse, paths):
         # Find files in the input path and add to list
         elif WILDCARD in root:
             # get the absolute path if not given
-            if not(os.path.isabs(root)):
+            if not os.path.isabs(root):
                 root = os.path.abspath(root)
 
             # Expand wildcard in the input path. Returns a list of files,
@@ -521,10 +504,6 @@ def findFiles(recurse, paths):
                 root = filesList[0]
 
             # get files from directory
-            """ Disabled JvdK: if enabled all files in direct child directories are analysed - do we really want that?
-            if os.path.isdir(root) and not recurse:
-                getFilesFromDir(root)
-            """
 
             # If the input path returned files list, add files to List
 
@@ -536,22 +515,16 @@ def findFiles(recurse, paths):
                     if os.path.isfile(f):
                         existingFiles.append(f)
 
-        elif os.path.isdir(root) == False and os.path.isfile(root) == False:
+        elif not os.path.isdir(root) and not os.path.isfile(root):
             # One or more (but not all) paths do no exist - print a warning
             msg = root + " does not exist"
-            printWarning(msg)
-
-        """ Disabled JvdK:
-        elif os.path.isdir(root) and not recurse:
-            #input path is a directory and is not recursive
-            getFilesFromDir(root)
-        """
+            shared.printWarning(msg)
 
         # RECURSION and WILDCARD IN RECURSION
         # Check if recurse in the input path
         if recurse:
             # get absolute input path if not given
-            if not(os.path.isabs(root)):
+            if not os.path.isabs(root):
                 root = os.path.abspath(root)
 
             if WILDCARD in root:
@@ -584,7 +557,7 @@ def findFiles(recurse, paths):
 
 
 def writeElement(elt, codec):
-    # Writes element as XML to stdout using defined codec
+    """Writes element as XML to stdout using defined codec"""
 
     # Element to string
     if config.PYTHON_VERSION.startswith(config.PYTHON_2):
@@ -592,7 +565,7 @@ def writeElement(elt, codec):
     if config.PYTHON_VERSION.startswith(config.PYTHON_3):
         xmlOut = ET.tostring(elt, 'unicode', 'xml')
 
-    if config.noPrettyXMLFlag == False:
+    if not config.noPrettyXMLFlag:
         # Make xml pretty
         xmlPretty = minidom.parseString(xmlOut).toprettyxml('    ')
 
@@ -619,15 +592,16 @@ def writeElement(elt, codec):
 
 
 def checkFiles(recurse, wrap, paths):
-    # This method checks the input argument path(s) for existing files and
-    # analyses them
+    """This method checks the input argument path(s) for existing files and
+    analyses them
+    """
 
     # Find existing files in the given input path(s)
     findFiles(recurse, paths)
 
     # If there are no valid input files then exit program
     checkNoInput(existingFiles)
-    
+
     # Set encoding of the terminal to UTF-8
     if config.PYTHON_VERSION.startswith(config.PYTHON_2):
         out = codecs.getwriter(config.UTF8_ENCODING)(sys.stdout)
@@ -637,9 +611,9 @@ def checkFiles(recurse, wrap, paths):
     # Wrap the xml output in <results> element, if wrapper flag is true
     if wrap or recurse:
         xmlHead = "<?xml version='1.0' encoding='UTF-8'?>\n"
-        xmlHead += "<results xmlns=\"http://openpreservation.org/ns/jpylyzer/\"\n"
-        xmlHead += "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n"
-        xmlHead += "xsi:schemaLocation=\"http://openpreservation.org/ns/jpylyzer/ http://jpylyzer.openpreservation.org/jpylyzer-v-1-1.xsd\">\n"
+        xmlHead += "<results xmlns=\"" + nsString + "\" "
+        xmlHead += "xmlns:xsi=\"" + xsiNsString + "\" "
+        xmlHead += "xsi:schemaLocation=\"" + locSchemaString + "\">\n"
     else:
         xmlHead = "<?xml version='1.0' encoding='UTF-8'?>\n"
     out.write(xmlHead)
@@ -649,7 +623,7 @@ def checkFiles(recurse, wrap, paths):
 
         # Analyse file
         xmlElement = checkOneFile(path)
-       
+
         # Write output to stdout
         writeElement(xmlElement, out)
 
@@ -659,6 +633,8 @@ def checkFiles(recurse, wrap, paths):
 
 
 def parseCommandLine():
+    """Parse command line arguments"""
+
     # Add arguments
     parser.add_argument('--verbose',
                         action="store_true",
@@ -670,7 +646,8 @@ def parseCommandLine():
                         action="store_true",
                         dest="inputRecursiveFlag",
                         default=False,
-                        help="when analysing a directory, recurse into subdirectories (implies --wrapper)")
+                        help="when analysing a directory, recurse into subdirectories \
+                                (implies --wrapper)")
     parser.add_argument('--wrapper',
                         '-w', action="store_true",
                         dest="inputWrapperFlag",
@@ -680,7 +657,8 @@ def parseCommandLine():
                         action="store_true",
                         dest="extractNullTerminatedXMLFlag",
                         default=False,
-                        help="extract null-terminated XML content from XML and UUID boxes(doesn't affect validation)")
+                        help="extract null-terminated XML content from XML and UUID boxes \
+                                (doesn't affect validation)")
     parser.add_argument('--nopretty',
                         action="store_true",
                         dest="noPrettyXMLFlag",
@@ -690,7 +668,8 @@ def parseCommandLine():
                         action="store",
                         type=str,
                         nargs='+',
-                        help="input JP2 image(s), may be one or more (whitespace-separated) path expressions; prefix wildcard (*) with backslash (\\) in Linux")
+                        help="input JP2 image(s), may be one or more (whitespace-separated) path \
+                                expressions; prefix wildcard (*) with backslash (\\) in Linux")
     parser.add_argument('--version', '-v',
                         action='version',
                         version=__version__)
@@ -698,10 +677,12 @@ def parseCommandLine():
     # Parse arguments
     args = parser.parse_args()
 
-    return(args)
+    return args
 
 
 def main():
+    """Main command line application"""
+
     # Get input from command line
     args = parseCommandLine()
 
