@@ -1,3 +1,4 @@
+"""Shared functions for jpylyzer sub-modules"""
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -19,19 +20,20 @@ import sys
 
 
 def printWarning(msg):
+    """Print warning to stderr"""
     msgString = ("User warning: " + msg + "\n")
     sys.stderr.write(msgString)
 
 
 def consecutive(lst):
-    # Returns True if items in lst are consecutive numbers
+    """Returns True if items in lst are consecutive numbers"""
     for i in range(1, len(lst)):
         if lst[i] - lst[i - 1] != 1:
-            return(False)
-    return(True)
+            return False
+    return True
 
 
 def listOccurrencesAreContiguous(lst, value):
-    # True if all occurrences of value in lst are at contiguous positions
+    """Returns True if all occurrences of value in lst are at contiguous positions"""
     indices_of_value = [i for i in range(len(lst)) if lst[i] == value]
     return consecutive(indices_of_value)
